{% extends "generic/object.html" %} {% block content %}
<div class="row">
  <div class="col col-md-6">
    <div class="card">
      <h5 class="card-header">{{object|meta:"verbose_name"|bettertitle}}</h5>
      <table class="table table-hover attr-table">
        <tr>
          <th scope="row">Object (Type)</th>
          <td>{{object.object_type.app_label|upper}}</td>
        </tr>
        <tr>
          <th scope="row">Object (ID)</th>
          <td>{{model_name|linkify}}</td>
        </tr>
        <tr>
          <th scope="row">Migration date</th>
          <td>{{object.date}}</td>
        </tr>
        <tr>
          <th scope="row">Cut</th>
          <td>{{object.cut}}</td>
        </tr>
        <tr>
          <th scope="row">Impact</th>
          <td>{{object.impact}}</td>
        </tr>
        <tr>
          <th scope="row">State</th>
          <td>{{object.state}}</td>
        </tr>

        <tr>
          <th scope="row">Description</th>
          <td>{{object.description|placeholder}}</td>
        </tr>

        <tr>
          <th scope="row">Created</th>
          <td>{{object.created}}</td>
        </tr>

        <tr>
          <th scope="row">Last updated</th>
          <td>{{object.last_updated}}</td>
        </tr>

      </table>
      <div></div>
    </div>
  </div>
  <div class="col col-md-6">
    {% include 'inc/panels/comments.html' %}
  </div>
</div>
{% endblock %}
