# Generated by Django 5.0.9 on 2024-11-27 15:03

import django.db.models.deletion
import taggit.managers
import utilities.json
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('core', '0012_job_object_type_optional'),
        ('extras', '0121_customfield_related_object_filter'),
    ]

    operations = [
        migrations.CreateModel(
            name='SopMigration',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False)),
                ('created', models.DateTimeField(auto_now_add=True, null=True)),
                ('last_updated', models.DateTimeField(auto_now=True, null=True)),
                ('custom_field_data', models.JSONField(blank=True, default=dict, encoder=utilities.json.CustomFieldJSONEncoder)),
                ('object_id', models.PositiveBigIntegerField()),
                ('date', models.DateTimeField()),
                ('cut', models.PositiveBigIntegerField()),
                ('impact', models.PositiveBigIntegerField()),
                ('state', models.CharField()),
                ('description', models.CharField(blank=True, max_length=200)),
                ('comments', models.TextField(blank=True)),
                ('object_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='core.objecttype')),
                ('tags', taggit.managers.TaggableManager(through='extras.TaggedItem', to='extras.Tag')),
            ],
            options={
                'verbose_name': 'Migration',
                'verbose_name_plural': 'Migrations',
                'ordering': ('object_type', 'pk', 'date'),
                'abstract': False,
            },
        ),
    ]
